==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Web/Gui/Resources/translations/Web_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <source>Previous page</source>
      <translation>Предыдущая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Go back to the previous page</source>
      <translation>Вернуться на предыдущую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Next page</source>
      <translation>Следующая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Go to the next page</source>
      <translation>Перейти на следующую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="130"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="131"/>
      <location filename="../../Command.cpp" line="132"/>
      <source>Refresh web page</source>
      <translation>Обновить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="246"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <location filename="../../Command.cpp" line="248"/>
      <source>Set URL</source>
      <translation>Установить URL</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <location filename="../../Command.cpp" line="160"/>
      <source>Stop loading</source>
      <translation>Остановить загрузку</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <location filename="../../Command.cpp" line="190"/>
      <source>Zoom in</source>
      <translation>Увеличить</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="218"/>
      <location filename="../../Command.cpp" line="219"/>
      <source>Zoom out</source>
      <translation>Уменьшить</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="47"/>
      <source>Open website...</source>
      <translation>Открыть сайт...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Открывает сайт в FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../BrowserView.cpp" line="785"/>
      <location filename="../../AppWebGui.cpp" line="85"/>
      <source>Browser</source>
      <translation>Браузер</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="597"/>
      <source>File does not exist!</source>
      <translation>Файл не существует!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="585"/>
      <location filename="../../BrowserView.cpp" line="590"/>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>Error</source>
      <translation>Ошибки</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="590"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Произошли ошибки при загрузке файла. Возможно, некоторые данные были изменены или не восстановлены. Посмотрите в окно отчета для более конкретной информации о затронутых объектах.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation>При загрузке файла возникли серьезные ошибки. Некоторые данные могли быть изменены или не восстановлены вообще. Сохранение проекта скорее всего приведет к потере данных.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="753"/>
      <source>Loading %1...</source>
      <translation>Загрузка %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="351"/>
      <source>Open in External Browser</source>
      <translation>Открыть во внешнем браузере</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="355"/>
      <source>Open in new window</source>
      <translation>Открыть в новом окне</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="387"/>
      <source>View source</source>
      <translation>Просмотр исходного кода</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Navigation</source>
      <translation>Навигация</translation>
    </message>
  </context>
</TS>

==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Web/Gui/Resources/translations/Web_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <source>Previous page</source>
      <translation>Предыдущая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Go back to the previous page</source>
      <translation>Вернуться на предыдущую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Next page</source>
      <translation>Следующая страница</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Go to the next page</source>
      <translation>Перейти на следующую страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="130"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="131"/>
      <location filename="../../Command.cpp" line="132"/>
      <source>Refresh web page</source>
      <translation>Обновить страницу</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="246"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <location filename="../../Command.cpp" line="248"/>
      <source>Set URL</source>
      <translation>Установить URL</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <location filename="../../Command.cpp" line="160"/>
      <source>Stop loading</source>
      <translation>Остановить загрузку</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <location filename="../../Command.cpp" line="190"/>
      <source>Zoom in</source>
      <translation>Увеличить</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="218"/>
      <location filename="../../Command.cpp" line="219"/>
      <source>Zoom out</source>
      <translation>Уменьшить</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Web</source>
      <translation>Интернет</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="47"/>
      <source>Open website...</source>
      <translation>Открыть сайт...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Открывает сайт в FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../BrowserView.cpp" line="815"/>
      <location filename="../../AppWebGui.cpp" line="93"/>
      <source>Browser</source>
      <translation>Браузер</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="623"/>
      <source>File does not exist!</source>
      <translation>Файл не существует!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="611"/>
      <location filename="../../BrowserView.cpp" line="616"/>
      <location filename="../../BrowserView.cpp" line="619"/>
      <source>Error</source>
      <translation>Ошибки</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="616"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Произошли ошибки при загрузке файла. Возможно, некоторые данные были изменены или не восстановлены. Посмотрите в окно отчета для более конкретной информации о затронутых объектах.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="619"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation>При загрузке файла возникли серьезные ошибки. Некоторые данные могли быть изменены или не восстановлены вообще. Сохранение проекта скорее всего приведет к потере данных.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="783"/>
      <source>Loading %1...</source>
      <translation>Загрузка %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="362"/>
      <source>Open in External Browser</source>
      <translation>Открыть во внешнем браузере</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="365"/>
      <source>Open in new window</source>
      <translation>Открыть в новом окне</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>View source</source>
      <translation>Просмотр кода страницы</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>Navigation</source>
      <translation>Навигация</translation>
    </message>
  </context>
</TS>
